MethodChannelBitlabs class

An implementation of BitlabsPlatform that uses method channels.

Inheritance

Constructors

MethodChannelBitlabs()

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addTag(String key, String value) → Future<void>
override
checkSurveys(void onResponse(bool), void onFailure(Exception)) → Future<void>
override
getSurveys(void onResponse(List<Survey>), void onFailure(Exception)) → Future<void>
override
init(String token, String uid) → Future<void>
override
launchOfferWall() → Future<void>
override
methodCallHandler(MethodCall call) → Future
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openMagicReceiptsMerchant(String merchantId) → Future<void>
override
openMagicReceiptsOffer(String offerId) → Future<void>
override
openOffer(String offerId) → Future<void>
override
requestTrackingAuthorization() → Future<void>
override
setOnRewardCallback(dynamic onReward(double reward)) → void
override
setTags(Map<String, dynamic> tags) → Future<void>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited